// Copyright 2025 Amazon.com, Inc. or its affiliates. All Rights Reserved.
//
// Licensed under the Apache License, Version 2.0 (the "License"). You may not
// use this file except in compliance with the License. A copy of the
// License is located at
//
// http://aws.amazon.com/apache2.0/
//
// or in the "license" file accompanying this file. This file is distributed
// on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
// either express or implied. See the License for the specific language governing
// permissions and limitations under the License.

package telemetrylog

import "time"

type Severity string

const (
	DEBUG    Severity = "DEBUG"
	INFO     Severity = "INFO"
	WARN     Severity = "WARN"
	ERROR    Severity = "ERROR"
	CRITICAL Severity = "CRITICAL"
)

type Entry struct {
	Time     time.Time `json:"Time"`
	Severity Severity  `json:"Severity"`
	Body     string    `json:"Body"`
}

type NamespaceLogs map[string][]Entry

type Log interface {
	EmitLog(s Severity, v ...interface{}) error
	EmitLogf(s Severity, format string, params ...interface{}) error
}
